@@ -241,7 +241,10 @@ pub mod fmt {
     ) {
         let (term, out) = &arena[current];
         match out {
-            TermOutput::Constant(n) => ::itoa::fmt(buf, *n).unwrap(),
+            TermOutput::Constant(n) => {
+                let mut itoa_buf = itoa::Buffer::new();
+                buf.push_str(itoa_buf.format(*n));
+            }
             TermOutput::DiceRoll(_total, partial_sums) => {
                 // TODO: use variant types to allow keeping direct references
                 // to specific type of term in the program output tree,
@@ -254,16 +257,20 @@ pub mod fmt {
                 };
                 if nonzero_dice {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push_str(" → ");
                     match partial_sums.as_deref() {
                         Some([first, rest @ ..]) => {
-                            itoa::fmt(&mut *buf, *first).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*first));
                             for part in rest {
                                 buf.push_str(" + ");
-                                itoa::fmt(&mut *buf, *part).unwrap();
+                                let mut itoa_buf = itoa::Buffer::new();
+                                buf.push_str(itoa_buf.format(*part));
                             }
                         }
                         Some([]) => unreachable!("groups of zero dice"),
@@ -279,9 +286,11 @@ pub mod fmt {
                     }
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                 }
             }
             TermOutput::KeepHigh(KeepHigh {
@@ -300,23 +309,28 @@ pub mod fmt {
                 } && *keep_count != 0;
                 if nonzero_dice {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push('k');
-                    itoa::fmt(&mut *buf, *keep_count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*keep_count));
                     buf.push_str(" → ");
                     match partial_sums.as_deref() {
                         Some([first, rest @ ..]) => {
                             buf.push_str("**");
-                            itoa::fmt(&mut *buf, *first).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*first));
                             let mut i = 1;
                             for part in rest {
                                 if i == *keep_count as usize {
                                     buf.push_str("**");
                                 }
                                 buf.push_str(" + ");
-                                itoa::fmt(&mut *buf, *part).unwrap();
+                                let mut itoa_buf = itoa::Buffer::new();
+                                buf.push_str(itoa_buf.format(*part));
                                 i += 1;
                             }
                             if i <= *keep_count as usize {
@@ -345,11 +359,14 @@ pub mod fmt {
                     }
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push('k');
-                    itoa::fmt(&mut *buf, *keep_count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*keep_count));
                 }
             }
             TermOutput::Add(_total, left, right) => {
@@ -373,7 +390,10 @@ pub mod fmt {
     fn fmt_short_impl(buf: &mut String, current: Id<Out>, arena: &Arena<Out>, terms: &Arena<Term>) {
         let (term, out) = &arena[current];
         match out {
-            TermOutput::Constant(n) => ::itoa::fmt(buf, *n).unwrap(),
+            TermOutput::Constant(n) => {
+                let mut itoa_buf = itoa::Buffer::new();
+                buf.push_str(itoa_buf.format(*n));
+            }
             TermOutput::DiceRoll(total, partial_sums) => {
                 // TODO: use variant types to allow keeping direct references
                 // to specific type of term in the program output tree,
@@ -386,16 +406,21 @@ pub mod fmt {
                 };
                 if nonzero_dice {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push_str(" → ");
-                    itoa::fmt(&mut *buf, *total).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*total));
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                 }
             }
             TermOutput::KeepHigh(KeepHigh {
@@ -414,20 +439,27 @@ pub mod fmt {
                 } && *keep_count != 0;
                 if nonzero_dice {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push('k');
-                    itoa::fmt(&mut *buf, *keep_count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*keep_count));
                     buf.push_str(" → ");
-                    itoa::fmt(&mut *buf, *total).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*total));
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(sides));
                     buf.push('k');
-                    itoa::fmt(&mut *buf, *keep_count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*keep_count));
                 }
             }
             TermOutput::Add(_total, left, right) => {
@@ -452,7 +484,8 @@ pub mod fmt {
         let mut buf = String::with_capacity(2000);
         fmt_default_impl(&mut buf, output.tree.top, &output.tree.arena, input);
         buf.push_str(" = ");
-        itoa::fmt(&mut buf, output.total).unwrap();
+        let mut itoa_buf = itoa::Buffer::new();
+        buf.push_str(itoa_buf.format(output.total));
         buf
     }
 
@@ -460,7 +493,8 @@ pub mod fmt {
         let mut buf = String::with_capacity(2000);
         fmt_short_impl(&mut buf, output.tree.top, &output.tree.arena, input);
         buf.push_str(" = ");
-        itoa::fmt(&mut buf, output.total).unwrap();
+        let mut itoa_buf = itoa::Buffer::new();
+        buf.push_str(itoa_buf.format(output.total));
         buf
     }
 }
