@@ -231,7 +231,8 @@ pub(super) fn fmt_default_impl(
     match output {
         Annotated(Annotation::Constant, val) => {
             if let Value(SV::Integer(int)) = &**val {
-                ::itoa::fmt(buf, *int).unwrap();
+                let mut itoa_buf = itoa::Buffer::new();
+                buf.push_str(itoa_buf.format(*int));
                 Ok(())
             } else {
                 Err(FormattingFailure::UnknownStructure)
@@ -241,21 +242,27 @@ pub(super) fn fmt_default_impl(
             if let Value(SV::Set(partial_sums)) = &**val {
                 if *count > 0 {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push_str(" → ");
                     let (first, rest) = (partial_sums[0], &partial_sums[1..]);
-                    itoa::fmt(&mut *buf, first).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(first));
                     for part in rest {
                         buf.push_str(" + ");
-                        itoa::fmt(&mut *buf, *part).unwrap();
+                        let mut itoa_buf = itoa::Buffer::new();
+                        buf.push_str(itoa_buf.format(*part));
                     }
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                 }
                 Ok(())
             } else {
@@ -286,34 +293,43 @@ pub(super) fn fmt_default_impl(
                     if let Value(SV::Set(unfiltered)) = &**roll {
                         if *count > 0 && *keep_count > 0 {
                             buf.push('(');
-                            itoa::fmt(&mut *buf, *count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*count));
                             buf.push('d');
-                            itoa::fmt(&mut *buf, *sides).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*sides));
                             buf.push_str(op);
-                            itoa::fmt(&mut *buf, *keep_count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*keep_count));
                             buf.push_str(" → ");
                             let (mut kept, mut unkept) = diff(filtered, unfiltered);
                             kept.reverse();
                             unkept.reverse();
                             let (first, rest) = (kept[0], &kept[1..]);
                             buf.push_str("**");
-                            itoa::fmt(&mut *buf, first).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(first));
                             for part in rest {
                                 buf.push_str(" + ");
-                                itoa::fmt(&mut *buf, *part).unwrap();
+                                let mut itoa_buf = itoa::Buffer::new();
+                                buf.push_str(itoa_buf.format(*part));
                             }
                             buf.push_str("**");
                             for part in unkept.into_iter() {
                                 buf.push_str(" + ");
-                                itoa::fmt(&mut *buf, *part).unwrap();
+                                let mut itoa_buf = itoa::Buffer::new();
+                                buf.push_str(itoa_buf.format(*part));
                             }
                             buf.push(')');
                         } else {
-                            itoa::fmt(&mut *buf, *count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*count));
                             buf.push('d');
-                            itoa::fmt(&mut *buf, *sides).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*sides));
                             buf.push_str(op);
-                            itoa::fmt(&mut *buf, *keep_count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*keep_count));
                         }
                         Ok(())
                     } else {
@@ -339,13 +355,16 @@ pub(super) fn fmt_default_impl(
                     .map_err(|()| FormattingFailure::UnknownStructure)?;
                 if iterations.len() >= 1 && iterations[0].len() > 0 {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push('!');
                     buf.push_str(" → ");
                     if let [&[first, ref first_rest @ ..], rest @ ..] = &*iterations {
-                        itoa::fmt(&mut *buf, first).unwrap();
+                        let mut itoa_buf = itoa::Buffer::new();
+                        buf.push_str(itoa_buf.format(first));
                         for (i, &part) in iter::once(first_rest)
                             .chain(rest.into_iter().copied())
                             .enumerate()
@@ -354,15 +373,18 @@ pub(super) fn fmt_default_impl(
                         {
                             buf.push_str(" + ");
                             (0..i).for_each(|_| buf.push('['));
-                            itoa::fmt(&mut *buf, part).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(part));
                             (0..i).for_each(|_| buf.push(']'));
                         }
                     }
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push('!');
                 }
                 Ok(())
@@ -406,7 +428,8 @@ pub(super) fn fmt_short_impl(
     match output {
         Annotated(Annotation::Constant, val) => {
             if let Value(SV::Integer(int)) = &**val {
-                ::itoa::fmt(buf, *int).unwrap();
+                let mut itoa_buf = itoa::Buffer::new();
+                buf.push_str(itoa_buf.format(*int));
                 Ok(())
             } else {
                 Err(FormattingFailure::UnknownStructure)
@@ -416,16 +439,21 @@ pub(super) fn fmt_short_impl(
             if let Value(SV::Set(partial_sums)) = &**val {
                 if *count > 0 {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push_str(" → ");
-                    ::itoa::fmt(&mut *buf, partial_sums.into_iter().sum::<i64>()).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(partial_sums.into_iter().sum::<i64>()));
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                 }
                 Ok(())
             } else {
@@ -456,20 +484,27 @@ pub(super) fn fmt_short_impl(
                     if let Value(SV::Set(_unfiltered)) = &**roll {
                         if *count > 0 && *keep_count > 0 {
                             buf.push('(');
-                            itoa::fmt(&mut *buf, *count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*count));
                             buf.push('d');
-                            itoa::fmt(&mut *buf, *sides).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*sides));
                             buf.push_str(op);
-                            itoa::fmt(&mut *buf, *keep_count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*keep_count));
                             buf.push_str(" → ");
-                            ::itoa::fmt(&mut *buf, filtered.into_iter().sum::<i64>()).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(filtered.into_iter().sum::<i64>()));
                             buf.push(')');
                         } else {
-                            itoa::fmt(&mut *buf, *count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*count));
                             buf.push('d');
-                            itoa::fmt(&mut *buf, *sides).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*sides));
                             buf.push_str(op);
-                            itoa::fmt(&mut *buf, *keep_count).unwrap();
+                            let mut itoa_buf = itoa::Buffer::new();
+                            buf.push_str(itoa_buf.format(*keep_count));
                         }
                         Ok(())
                     } else {
@@ -495,17 +530,22 @@ pub(super) fn fmt_short_impl(
                     .map_err(|()| FormattingFailure::UnknownStructure)?;
                 if iterations.len() >= 1 && iterations[0].len() > 0 {
                     buf.push('(');
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push('!');
                     buf.push_str(" → ");
-                    itoa::fmt(&mut *buf, iterations.into_iter().flatten().sum::<i64>()).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(iterations.into_iter().flatten().sum::<i64>()));
                     buf.push(')');
                 } else {
-                    itoa::fmt(&mut *buf, *count).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*count));
                     buf.push('d');
-                    itoa::fmt(&mut *buf, *sides).unwrap();
+                    let mut itoa_buf = itoa::Buffer::new();
+                    buf.push_str(itoa_buf.format(*sides));
                     buf.push('!');
                 }
                 Ok(())
@@ -547,7 +587,8 @@ pub fn mbot_format_default(output: &OutputNode, total: i64) -> String {
     // as overflow would've already occurred in computing the total.
     fmt_default_impl(&mut buf, output).unwrap();
     buf.push_str(" = ");
-    itoa::fmt(&mut buf, total).unwrap();
+    let mut itoa_buf = itoa::Buffer::new();
+    buf.push_str(itoa_buf.format(total));
     buf
 }
 
@@ -558,6 +599,7 @@ pub fn mbot_format_short(output: &OutputNode, total: i64) -> String {
     // as overflow would've already occurred in computing the total.
     fmt_short_impl(&mut buf, output).unwrap();
     buf.push_str(" = ");
-    itoa::fmt(&mut buf, total).unwrap();
+    let mut itoa_buf = itoa::Buffer::new();
+    buf.push_str(itoa_buf.format(total));
     buf
 }
