@@ -195,12 +195,15 @@ fn write_sexpr(terms: &Arena<Term>, top: Id<Term>, buf: &mut String) {
     };
     match terms[top] {
         Term::Constant(n) => {
-            itoa::fmt(&mut *buf, n).unwrap();
+            let mut itoa_buf = itoa::Buffer::new();
+            buf.push_str(itoa_buf.format(n));
         }
         Term::DiceRoll(count, faces) => {
-            itoa::fmt(&mut *buf, count).unwrap();
+            let mut itoa_buf = itoa::Buffer::new();
+            buf.push_str(itoa_buf.format(count));
             buf.push('d');
-            itoa::fmt(&mut *buf, faces).unwrap();
+            let mut itoa_buf = itoa::Buffer::new();
+            buf.push_str(itoa_buf.format(faces));
         }
         Term::KeepHigh(roll, count) => {
             buf.push('(');
@@ -208,7 +211,8 @@ fn write_sexpr(terms: &Arena<Term>, top: Id<Term>, buf: &mut String) {
             buf.push(' ');
             write_sexpr(terms, roll, &mut *buf);
             buf.push(' ');
-            itoa::fmt(&mut *buf, count).unwrap();
+            let mut itoa_buf = itoa::Buffer::new();
+            buf.push_str(itoa_buf.format(count));
             buf.push(')');
         }
         Term::KeepLow(roll, count) => {
@@ -217,7 +221,8 @@ fn write_sexpr(terms: &Arena<Term>, top: Id<Term>, buf: &mut String) {
             buf.push(' ');
             write_sexpr(terms, roll, &mut *buf);
             buf.push(' ');
-            itoa::fmt(&mut *buf, count).unwrap();
+            let mut itoa_buf = itoa::Buffer::new();
+            buf.push_str(itoa_buf.format(count));
             buf.push(')');
         }
         Term::Explode(roll) => {
