@@ -24,7 +24,8 @@ impl IdGen {
 impl Id {
     pub(crate) fn fmt(&self, buf: &mut String) {
         buf.push('N');
-        ::itoa::fmt(buf, self.0).unwrap();
+        let mut itoa_buf = itoa::Buffer::new();
+        buf.push_str(itoa_buf.format(self.0));
     }
 }
 
